@@ -24,4 +24,4 @@ def ph_command(cmd, path):
             the dictionary that specify the py and yaml file
     """
     context = PhContextFacade(cmd, path)
-    context.execute()
+    return context.execute()
